/* emacs: this is -*- c++ -*- */
/**
 **   @file    convert.h
 **       
 **            converter function to convert to anf from 
 **            appl::TH!D Aand root TH1D, in case applgrid itself
 **            was compiled without root
 **                   
 **   @author  sutt
 **   @date    Sun 21 Mar 2021 11:38:51 GMT
 **
 **   $Id: convert.h, v0.0   Sun 30 Mar 2021 11:38:51 GMT sutt $
 **
 **   Copyright (C) 2021 sutt (sutt@cern.ch)    
 **
 **/


#ifndef APPLCONVCONVERT
#define APPLCONVCONVERT

#ifndef USEROOT


TH1D*       convert( const  appl::TH1D* h );
appl::TH1D* convert( const        TH1D* h );


// convertors to and from root histograms

inline appl::TH1D* convert( ::TH1D* h ) { 
  std::vector<double> limits(h->GetNbinsX()+1);
  for ( size_t i=0 ; i<limits.size() ; i++ ) limits[i] = h->GetBinLowEdge(i+1);
  appl::TH1D* hist = new appl::TH1D( h->GetName(), h->GetTitle(), limits.size()-1, &limits[0] );
  for ( size_t i=0 ; i<hist->size() ; i++ ) { 
    hist->y(i)  = h->GetBinContent(i+1);
    hist->ye(i) = h->GetBinError(i+1);
  }
  return hist;
}


inline ::TH1D* convert( const appl::TH1D* h ) { 
  ::TH1D* hist = new ::TH1D( h->name().c_str(), h->GetTitle().c_str(), h->size(), &(h->xlimits()[0]) );
  for ( size_t i=0 ; i<h->size() ; i++ ) { 
    hist->SetBinContent(i+1, h->y(i) ); 
    hist->SetBinError(i+1, h->ye(i) ); 
  }
  return hist;
}


inline ::TH1D* convert( const appl::TH1D& h ) { 
  ::TH1D* hist = new ::TH1D( h.name().c_str(), h.GetTitle().c_str(), h.size(), &(h.xlimits()[0]) );
  for ( size_t i=h.size() ; i-- ; ) { 
    hist->SetBinContent(i+1, h.y(i) ); 
    hist->SetBinError(i+1, h.ye(i) ); 
  }
  return hist;
}


#endif /// USEROOT

#endif /// APPLCONVCONVERT
